//
//  ViewController.m
//  TwoColumnGridFromTwoDataSources
//
//  Created by Stephen Zaharuk on 1/7/15.
//  Copyright (c) 2015 Infragistics. All rights reserved.
//

#import "ViewController.h"


// The private variables are contained in the brackets.
// Private methods could be below that, but I haven't figured out why someone would do that because
// if you don't put the method definition in the header file, then it's already private so... ?
@interface ViewController ()<IGGridViewDelegate>
    {
        IGGridView* theGridView;
        IGGridViewDataSourceHelper* _dsh;
        
    }
@end


// This is just a generic ol' view controller where we override the viewDidLoad method.
@implementation ViewController

    - (void)viewDidLoad
    {
        [super viewDidLoad];
        
        [self configureGridViewAndAddToUI];
        
        [self assignDelegateAndDatasource];
    }

    -(void)configureGridViewAndAddToUI
    {
        // Create and size a grid view.
        CGRect theGridRectangle = CGRectMake(0, 20, 375, 650);
        theGridView = [[IGGridView alloc]initWithFrame:theGridRectangle];

        // Set additional properties to configure the grid view
        theGridView.headerHeight = 0;
        theGridView.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
        theGridView.selectionType = IGGridViewSelectionTypeCell;
        theGridView.delegate = self;
        theGridView.rowHeight = 40;
        
        theGridView.emptyRows = NO;
        
        // Add the grid view to the user interface.
        [self.view addSubview:theGridView];
    }


    -(void)assignDelegateAndDatasource
    {
        Person* p = [[Person alloc]init];
        p.name = @"Tim Smith";
        p.age = 30;
        p.birthDate = [NSDate date];
        p.height = @"6'0";
        p.weight = @"170lbs";
        p.recordNumber = 1;
        
        Person* p2 = [[Person alloc]init];
        p2.name = @"John doe";
        p2.age = 30;
        p2.birthDate = [NSDate date];
        p2.height = @"5'10";
        p2.weight = @"145lbs";
        p2.recordNumber = 2;
        
        NSMutableArray* data = [[NSMutableArray alloc]initWithObjects:p, p2, nil];
        
        _dsh = [[TransposedDataSourceHelper alloc]init];
        _dsh.groupingKey = @"recordNumber";
        _dsh.data = data;
        
        theGridView.dataSource = _dsh;
    }


-(IGCellPath *)gridView:(IGGridView *)gridView willSelectCellAtPath:(IGCellPath *)path
{
    if(path.isFixed == IGGridViewFixedColumnDirectionNone)
    {
        NSObject* val = [_dsh resolveDataValueForCell:path];
        // Put display popover code here.
        UIAlertView* alert = [[UIAlertView alloc]initWithTitle:@"Clicked" message:val.description delegate:nil cancelButtonTitle:@"Ok" otherButtonTitles:nil];
        
        [alert show];
    }
    
    return nil; // Don't selecdt anything.
}



@end


@implementation Person
@end

@implementation TransposedDataSourceHelper

// the number of columns in this case will be the number of rows for a normal grid (since we are flipping the two).
-(NSInteger)numberOfColumnsInGridView:(IGGridView *)gridView
{
    return [super gridView:gridView numberOfRowsInSection:0];
}

// And similarly the number of rows in this case will be the number of columns in a normal grid
-(NSInteger)gridView:(IGGridView *)gridView numberOfRowsInSection:(NSInteger)section
{
    return [super numberOfColumnsInGridView:gridView];
}

// Since we are flipping the columns and the rows when we want this method call to flip them for us
-(IGCellPath *)normalizePath:(IGCellPath *)path {
    return [IGCellPath pathForRow:path.columnIndex inSection:path.sectionIndex inColumn:path.rowIndex];
}

// And this reverses the change made in normalizePath.
-(IGCellPath *)deNormalizePath:(IGCellPath *)path
{
    return [IGCellPath pathForRow:path.columnIndex inSection:path.sectionIndex inColumn:path.rowIndex];
}

// We will use the fixed left column to hold the column headers now moved to be row headers.  So mark a single column as fixed.
-(NSInteger)numberOfFixedLeftColumnsInGridView:(IGGridView *)gridView
{
    return 1;
    
}

// When the fixed column cells are being rendered, we will want to take control of that process to show the row headers for the row.  We will put the column header text into the cell.
-(IGGridViewCell *)gridView:(IGGridView *)gridView fixedLeftCellAt:(IGCellPath *)path
{
    IGGridViewCell* c = [gridView dequeueReusableCellWithIdentifier:@"fc"];
    
    if (!c)
    {
        c= [[IGGridViewCell alloc]initWithReuseIdentifier:@"fc"];
    }
    
    NSString* columnHeader = ((IGGridViewColumnDefinition*) self.columns[path.rowIndex]).headerText;
    c.textLabel.text = columnHeader;
    return c;
    
}

@end

